Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(412)

Unified Diff: tools/telemetry/telemetry/internal/platform/profiler/tcmalloc_heap_profiler.py

Issue 1533523004: Run codespell on src/tools/telemetry. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/telemetry/telemetry/internal/platform/profiler/tcmalloc_heap_profiler.py
diff --git a/tools/telemetry/telemetry/internal/platform/profiler/tcmalloc_heap_profiler.py b/tools/telemetry/telemetry/internal/platform/profiler/tcmalloc_heap_profiler.py
index bfc6e1a5628704146f1e46b2fd5e0efe6f5db2ca..a11ae4cd6466dd399b2b084184e3f877227deafd 100644
--- a/tools/telemetry/telemetry/internal/platform/profiler/tcmalloc_heap_profiler.py
+++ b/tools/telemetry/telemetry/internal/platform/profiler/tcmalloc_heap_profiler.py
@@ -9,7 +9,7 @@ import sys
from telemetry.internal.backends.chrome import android_browser_finder
from telemetry.internal.platform import profiler
# Enviroment variables to (android properties, default value) mapping.
_ENV_VARIABLES = {
'HEAP_PROFILE_TIME_INTERVAL': ('heapprof.time_interval', 20),
'HEAP_PROFILE_MMAP': ('heapprof.mmap', 1),
@@ -87,7 +87,7 @@ class _TCMallocHeapProfilerLinux(object):
if key not in os.environ:
msg += '%s=%s ' % (key, str(values[1]))
if msg:
- raise Exception('Need enviroment variables, try again with:\n %s' % msg)
+ raise Exception('Need environment variables, try again with:\n %s' % msg)
if not os.path.exists(os.environ['HEAPPROFILE']):
os.makedirs(os.environ['HEAPPROFILE'])
assert os.path.isdir(os.environ['HEAPPROFILE']), 'HEAPPROFILE is not a dir'
@@ -9,7 +9,7 @@ import sys
from telemetry.internal.backends.chrome import android_browser_finder
from telemetry.internal.platform import profiler
-# Enviroment variables to (android properties, default value) mapping.
+# Environment variables to (android properties, default value) mapping.
_ENV_VARIABLES = {
'HEAP_PROFILE_TIME_INTERVAL': ('heapprof.time_interval', 20),

Powered by Google App Engine
This is Rietveld 408576698